<?php
/**
  * Plugin Name: HR Office Vacancy Listing
  * Plugin URI: https://hroffice.eu/
  * Description: HROffice Vacancy Listing allows you to Create shortcode for Vacancy listing
  * Version: 1.0.6
  * Requires at least: 6.0
  * Requires PHP: 7.4
  * Author: HR Office
  * Author URI: https://nowonlineutrecht.atlassian.net/wiki/spaces/HRAD/overview
  * License: GPLv2 or later
  * Text Domain: hr_office_vacancy_domain
  * Domain Path: /languages/
*/

define( 'HR_OFFICE_VACANCY_PLUGIN_DIR_URL', plugin_dir_url( __FILE__ ) );

// Load plugin translation.
function hr_office_vacancy_listing_load_textdomain() {
    load_plugin_textdomain( 'hr_office_vacancy_domain', false, basename( dirname( __FILE__ ) ) . '/languages/' );
}
add_action( 'init', 'hr_office_vacancy_listing_load_textdomain' );

//Plugin Post Type
include(plugin_dir_path( __FILE__ ) . 'admin/plugin-post-type.php');
//Plugin Meta box
include(plugin_dir_path( __FILE__ ) . 'admin/plugin-post-metabox.php');
//Plugin API ajax call
include(plugin_dir_path( __FILE__ ) . 'admin/plugin-api-ajax-call.php');
//Listing url settings
include(plugin_dir_path( __FILE__ ) . 'front/plugin-shortcode-url-settings.php');
//Listing Shortcode
$fsurl = get_stylesheet_directory().'/hr-office-vacancy-listing/plugin-listing-shortcode.php'; 
if(file_exists($fsurl)){  
  include($fsurl);
}else{  
  include(plugin_dir_path( __FILE__ ) . 'front/plugin-listing-shortcode.php');
}
//Listing ajax data
include(plugin_dir_path( __FILE__ ) . 'front/plugin-listing-ajax-data.php');
//Apply Form ajax data
include(plugin_dir_path( __FILE__ ) . 'front/plugin-apply-form-ajax-data.php');
//License Key admin page
include(plugin_dir_path( __FILE__ ) . 'admin/plugin-license-key-settings.php');
//Cron License check admin page
include(plugin_dir_path( __FILE__ ) . 'admin/plugin-cron-license-check.php');

// Add JavaScripts in plugin
function hr_office_vacancy_enqueue_script() {   
    wp_enqueue_style( 'hr_office_vacancy_style',  plugin_dir_url( __FILE__ ). 'assets/css/hr_office_vacancy_style.css');
    wp_enqueue_script( 'hr_office_vacancy_js', plugin_dir_url( __FILE__ ) . 'assets/js/hr_office_vacancy_js.js', array('jquery'), '1.0', true );
}
add_action('wp_enqueue_scripts', 'hr_office_vacancy_enqueue_script');

function hr_office_vacancy_enqueue_script_admin() { 
    wp_enqueue_style( 'wp-color-picker' );
    wp_enqueue_style( 'hr_office_vacancy_admin_style',  plugin_dir_url( __FILE__ ). 'assets/css/hr_office_vacancy_admin_style.css');
    
    wp_enqueue_script( 'hr_office_vacancy_admin_js', plugin_dir_url( __FILE__ ) . 'assets/js/hr_office_vacancy_admin_js.js', array('jquery'), '1.0', true );
    
    $localize_script_array = array(
      'ajaxurl' => admin_url('admin-ajax.php'),
      'api_empty_msg' => __( 'Please Enter your API credentials', 'hr_office_vacancy_domain' ),
      'api_working_msg' => __( 'Working', 'hr_office_vacancy_domain' ), 
      'api_notworking_msg' => __( 'Not Working', 'hr_office_vacancy_domain' ),       
    );
    wp_localize_script( 'hr_office_vacancy_admin_js', 'frontend_ajax_object', $localize_script_array );
    wp_enqueue_script( 'meta-box-color-js', plugin_dir_url( __FILE__ ) . 'assets/js/meta-box-color.js', array('wp-color-picker'), '1.0', true );  
}
add_action('admin_enqueue_scripts', 'hr_office_vacancy_enqueue_script_admin');

//Plugin Settings Link
function hr_office_vacancy_listing_settings_link($links) { 
  $status  = get_option( 'hr_office_vacancy_plugin_license_status' );
  
  if($status == 'valid'){
    $settings_link = '<a href="edit.php?post_type=hroffice_vacn_shortc">Settings</a>';
  }else{
    $settings_link = '<a href="edit.php?post_type=hroffice_vacn_shortc&page=license_configuration">Settings</a>';
  }
   
  array_unshift($links, $settings_link); 
  return $links; 
}
$pluginfile = plugin_basename(__FILE__); 
add_filter("plugin_action_links_$pluginfile", 'hr_office_vacancy_listing_settings_link' );


//Update Checker
if( ! class_exists('hrofficevacancypluginUpdateChecker') ) {

  class hrofficevacancypluginUpdateChecker{

    public $plugin_slug;
    public $version;
    public $cache_key;
    public $cache_allowed;

    public function __construct() {

      require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
      $plugin_data = get_plugin_data( __FILE__ );

      $this->plugin_slug = plugin_basename( __DIR__ );
      $this->version = $plugin_data['Version'];
      $this->cache_key = 'hrofficeupdate_checker_custom_upd';
      $this->cache_allowed = false;

      add_filter( 'plugins_api', array( $this, 'info' ), 20, 3 );
      add_filter( 'site_transient_update_plugins', array( $this, 'update' ) );
      add_action( 'upgrader_process_complete', array( $this, 'purge' ), 10, 2 );

    }

    public function request(){

      $remote = get_transient( $this->cache_key );

      if( false === $remote || ! $this->cache_allowed ) {

        $remote = wp_remote_get(
          'https://nexuslink.in/wpmediaupload/plugins/info-hr-office-plug.json',
          array(
            'timeout' => 10,
            'headers' => array(
              'Accept' => 'application/json'
            )
          )
        );

        if(
          is_wp_error( $remote )
          || 200 !== wp_remote_retrieve_response_code( $remote )
          || empty( wp_remote_retrieve_body( $remote ) )
        ) {
          return false;
        }

        set_transient( $this->cache_key, $remote, DAY_IN_SECONDS );

      }

      $remote = json_decode( wp_remote_retrieve_body( $remote ) );

      return $remote;

    }


    function info( $res, $action, $args ) {

      // do nothing if you're not getting plugin information right now
      if( 'plugin_information' !== $action ) {
        return $res;
      }

      // do nothing if it is not our plugin
      if( $this->plugin_slug !== $args->slug ) {
        return $res;
      }

      // get updates
      $remote = $this->request();

      if( ! $remote ) {
        return $res;
      }

      $res = new stdClass();

      $res->name = $remote->name;
      $res->slug = $remote->slug;
      $res->version = $remote->version;
      $res->tested = $remote->tested;
      $res->requires = $remote->requires;
      $res->author = $remote->author;
      $res->author_profile = $remote->author_profile;
      $res->download_link = $remote->download_url;
      $res->trunk = $remote->download_url;
      $res->requires_php = $remote->requires_php;
      $res->last_updated = $remote->last_updated;

      $res->sections = array(
        'description' => $remote->sections->description,
        'installation' => $remote->sections->installation,
        'changelog' => $remote->sections->changelog
      );

      if( ! empty( $remote->banners ) ) {
        $res->banners = array(
          'low' => $remote->banners->low,
          'high' => $remote->banners->high
        );
      }

      return $res;

    }

    public function update( $transient ) {

      if ( empty($transient->checked ) ) {
        return $transient;
      }

      $remote = $this->request();

      if(
        $remote
        && version_compare( $this->version, $remote->version, '<' )
        && version_compare( $remote->requires, get_bloginfo( 'version' ), '<=' )
        && version_compare( $remote->requires_php, PHP_VERSION, '<' )
      ) {
        $res = new stdClass();
        $res->slug = $this->plugin_slug;
        $res->plugin = plugin_basename( __FILE__ ); // misha-update-plugin/misha-update-plugin.php
        $res->new_version = $remote->version;
        $res->tested = $remote->tested;
        $res->package = $remote->download_url;

        $transient->response[ $res->plugin ] = $res;

      }

      return $transient;

    }

    public function purge( $upgrader, $options ){

      if (
        $this->cache_allowed
        && 'update' === $options['action']
        && 'plugin' === $options[ 'type' ]
      ) {
        // just clean the cache when new plugin version is installed
        delete_transient( $this->cache_key );
      }

    }


  }

  new hrofficevacancypluginUpdateChecker();

}